@@ -19,7 +19,7 @@ use File::Basename;
 use IPC::Run qw(run);
 use Cwd;
 
-our $VERSION = "0.07";
+our $VERSION = "0.08";
 
 ###########################################
 sub new {
@@ -49,6 +49,14 @@ sub new {
     bless $self, $class;
 }
 
+###########################################
+sub tardir {
+###########################################
+    my($self) = @_;
+
+    return $self->{tardir};
+}
+
 ###########################################
 sub read {
 ###########################################
@@ -263,7 +271,7 @@ sub list_next {
       my($type, $entry) = split / /, $line, 2;
       redo if $type eq "d" and ! $self->{dirs};
       $self->offset(tell FILE);
-      return [$entry, File::Spec->catfile($self->{tmpdir}, "tar", $entry), 
+      return [$entry, File::Spec->catfile($self->{tardir}, $entry), 
               $type];
     }
 }
@@ -281,7 +289,7 @@ sub offset {
         close FILE;
     }
 
-    open FILE, "<$offset_file" or LOGDIE "Can't open $offset_file";
+    open FILE, "<$offset_file" or LOGDIE "Can't open $offset_file (Did you call list_next() without a previous list_reset()?)";
     my $offset = <FILE>;
     chomp $offset;
     return $offset;
@@ -527,6 +535,12 @@ Write out the tarball by tarring up all temporary files and directories
 and store it in C<$tarfile> on disk. If C<$compress> holds a true value,
 compression is used.
 
+=item B<$arch-E<gt>tardir()>
+
+Return the directory the tarball was unpacked in. This is sometimes useful
+to play dirty tricks on C<Archive::Tar::Wrapper> by mass-manipulating
+unpacked files before wrapping them back up into the tarball.
+
 =back
 
 =head1 KNOWN LIMITATIONS
